Pydenticon
==========

Pydenticon is a small utility library that can be used for deterministically
generating identicons based on the hash of provided data.

The implementation is a port of the Sigil identicon implementation from:

* https://github.com/cupcake/sigil/

Pydenticon provides a couple of extensions of its own when compared to the
original Sigil implementation, like:

* Ability to supply custom digest algorithms (allowing for larger identicons if
  digest provides enough entropy).
* Ability to specify a rectangle for identicon size..
